var MadFrontend = (function($) {

	'use strict';

	var App = {},
		$body = $('body'),
		$doc = $(document);

	App.modules = {};
	App.helpers = {};

	App.ISTOUCH = Modernizr.touchevents;
	App.EVENT = App.ISTOUCH ? 'touchstart' : 'click';
	App.ANIMATIONDURATION = 500;
	App.ANIMATIONEASING = 'easeOutQuart';
	App.ANIMATIONSUPPORTED = Modernizr.cssanimations;
	App.ANIMATIONEND = "webkitAnimationEnd mozAnimationEnd MSAnimationEnd oanimationend animationend";
	App.RTL = getComputedStyle(document.body).direction === 'rtl';

	App.afterDOMReady = function() {

		if ( this.modules.preloader ) { this.modules.preloader(); }

		if ( $('.site-search-btn').length ) this.modules.searchClick();

		if ( $('.main-navigation').length ) this.modules.navInit();

		if ( $('.site-header__cart-wrapper').length ) { this.modules.Cart(); }

		if(window.MadStickyHeaderSection) {
			var $stickySections = $('[class*="mad-header-section--sticky"]');

			if($stickySections.length) {
				new window.MadStickyHeaderSection($stickySections, {
					animationEasing: self.ANIMATIONEASING,
					animationDuration: self.ANIMATIONDURATION
				});
			}
		}


		if ( this.modules.backToTop ) {
			this.modules.backToTop({
				easing: 'easeOutQuint',
				speed: 550,
				cssPrefix: 'mad-'
			});
		}

		/* ---------------------------------------------------- */
		/*	Custom Select										                    */
		/* ---------------------------------------------------- */

		if ( $('.mad-custom-select').length ) {
			$.MadCustomSelects();
		}

	}

	/* ----------------------------------------
	 Search
	 ---------------------------------------- */

	App.modules.searchClick = function () {

		$.searchClick = function (el, options) {
			this.el = $(el);
			this.init(options);
		}

		$.searchClick.DEFAULTS = {
			key_esc: 27
		}

		$.searchClick.prototype = {
			init: function (options) {
				var base = this;
				base.o = $.extend({}, $.searchClick.DEFAULTS, options);
				base.key_esc = base.o.key_esc;

				base.searchWrap = this.el.parents('.site-header__search');
				base.searchBar = $('.site-header__search-bar', base.searchWrap)
				base.searchClose = $('.site-close-search-form', base.el);
				base.searchField = $('[name="s"]', base.el);
				base.event = Modernizr.touch ? 'touchstart' : 'click';

				base.set();
				base.bind(base);
			},
			set: function () {
				var transEndEventNames = {
					'WebkitTransition': 'webkitTransitionEnd',
					'MozTransition': 'transitionend',
					'OTransition': 'oTransitionEnd',
					'msTransition': 'MSTransitionEnd',
					'transition': 'transitionend'
				};
				this.transEndEventName = transEndEventNames[Modernizr.prefixed( 'transition' )];
				this.animations = Modernizr.csstransitions;
			},
			bind: function (self) {

				$('body').on( this.event, '.site-close-search-form', $.proxy(function (e) {
					this.display_hide(e, this.key_esc);
				}, this) )
					.on( this.event, '.site-search-btn', $.proxy(this.display_show, this));

				this.keyDownHandler(this.key_esc);

				$(window).on('load',function() {
					self.searchWrap.on('click', function(e) {
						if ( e.target === self.searchBar[0] ) {
							self.searchWrap.removeClass('opened');
						}
					});
				});

			},
			hide: function () {
				var base = this;
				base.searchWrap.addClass('closed').removeClass('opened');
				var onEndTransitionFn = function () {
					base.searchWrap.removeClass('closed');
				};
				if ( base.animations ) {
					base.searchWrap.on(base.transEndEventName, onEndTransitionFn);
				} else {
					onEndAnimationFn();
				}

			},
			display_show: function (e) {
				e.preventDefault();

				if (!this.searchWrap.hasClass('opened')) {
					this.searchWrap.addClass('opened');
					this.searchField.focus();
				}
			},
			display_hide: function (e, key) {
				var base = this;

				if (base.searchWrap.hasClass('opened')) {
					if (e.type == base.event || e.type == 'keydown' && e.keyCode === key) {
						e.preventDefault();
						base.hide();
						base.searchField.blur();
					}
				}
			},
			keyDownHandler: function (key) {
				$(window).on('keydown', $.proxy(function (e) {
					this.display_hide(e, key);
				}, this));
			}
		}

		var searchForm = $('.site-header__search-bar');
		if ( searchForm.length ) {
			searchForm.searchClick();
		}

	}

	/* ----------------------------------------
	 Preloader
	 ---------------------------------------- */

	App.modules.preloader = function() {
		var $preloader = $('.mad-preloader'),
			leftPos = parseInt($preloader.css('margin-left'), 10),
			topPos = parseInt($preloader.css('margin-top'), 10),
			$w = $(window),
			$nav = $('.mad-navigation, .mad-navigation-vertical');

		if($nav.length) {
			$nav.off('click.MadPreloader').on('click.MadPreloader', 'a', function(event){

				var $circle = $('<div></div>', {
					style: 'left: '+ event.clientX +'px; top: '+ event.clientY +'px;',
					class: 'mad-preloader-circle'
				});

				if($body.hasClass('mad-body--moving-to-another-page')) {
					$circle.appendTo($body);

					setTimeout(function(){
						$circle.addClass('mad-preloader-circle--appearing');
					}, 20);
				}
			});
		}

		if(!$preloader.length) return;

		$body.off('mousemove.MadPreloader').on('mousemove.MadPreloader', function(event) {
			$preloader.css({
				'margin-left': leftPos - ($w.width() / 2 - event.pageX),
				'margin-top': topPos - ($w.height() / 2 - (event.pageY - $w.scrollTop())),
			});
		}).jQueryImagesLoaded().then(function(){

			$preloader.addClass('mad-preloader--disappearing');
			setTimeout(function() {
				$preloader.remove();
				$body.off('mousemove.MadPreloader');
			}, 700);
		});
	};

	/* ----------------------------------------
	 Back to top
	 ---------------------------------------- */

	App.modules.backToTop = function(config) {

		var backToTop = {

			init: function(config){

				var self = this;

				if(config) this.config = $.extend(this.config, config);

				this.btn = $('<button></button>', {
					'class': self.config.cssPrefix+'back-to-top animated stealthy',
					html: '<span class="icon material-icons">expand_less</span>'
				});

				this.bindEvents();

				$body.append(this.btn);

			},

			config: {
				breakpoint: 700,
				showClass: 'zoomIn',
				hideClass: 'zoomOut',
				easing: 'linear',
				speed: 500,
				cssPrefix: ''
			},

			bindEvents: function(){

				var page = $('html, body'),
					self = this;

				this.btn.on('click', function(e){

					page.stop().animate({
						scrollTop: 0
					}, {
						easing: self.config.easing,
						duration: self.config.speed
					});

				});

				this.btn.on(App.ANIMATIONEND, function(e){

					e.preventDefault();

					var $this = $(this);

					if($this.hasClass(self.config.hideClass)){

						$this
							.addClass('stealthy')
							.removeClass(self.config.hideClass + " " + self.config.cssPrefix + "inview");

					}

				});

				$(window).on('scroll.backtotop', { self: this}, this.toggleBtn);

			},

			toggleBtn: function(e){

				var $this = $(this),
					self = e.data.self;

				if($this.scrollTop() > self.config.breakpoint && !self.btn.hasClass(self.config.cssPrefix + 'inview')){

					self.btn
						.addClass(self.config.cssPrefix + 'inview')
						.removeClass('stealthy');

					if(App.ANIMATIONSUPPORTED){
						self.btn.addClass(self.config.showClass);
					}

				}
				else if($this.scrollTop() < self.config.breakpoint && self.btn.hasClass(self.config.cssPrefix + 'inview')){

					self.btn.removeClass(self.config.cssPrefix + 'inview');

					if(!App.ANIMATIONSUPPORTED){
						self.btn.addClass('stealthy');
					}
					else{
						self.btn.removeClass(self.config.showClass)
							.addClass(self.config.hideClass);
					}

				}

			}

		};

		backToTop.init(config);

		return this;

	};

	App.modules.dropInit = function() {




	}

	/* ----------------------------------------
	 Cart
	 ---------------------------------------- */

	App.modules.Cart = function() {

		var $cartWrapper = $('.site-header__cart-wrapper');

		$('body').on('click', '.site-header__cart-toggle', function(e) {
			e.preventDefault();

			if ( !$cartWrapper.hasClass('active') ) {
				$cartWrapper.addClass('active');
			} else {
				$cartWrapper.removeClass('active');
			}

		});

		$(document).on( 'click', function( e ) {
			if (!$(e.target).closest($cartWrapper).length) {
				$cartWrapper.removeClass('active')
			}
		} );

	}


	/* ----------------------------------------
	 Sticky Header
	 ---------------------------------------- */

	App.modules.stickyHeader = function() {

		if ( $('#wpadminbar').length && $('#wpadminbar').is(':visible') ) {
			$('.site-sticky-header').css('top', $('#wpadminbar').height());
		}

		$(window).scroll(function () {

			var top = $(window).scrollTop();

			if ( top >= MAD.header_sticky_offset ) {
				if (!$('body').hasClass('sticky-header-on')) {
					$('body').addClass('sticky-header-on');
				}
			} else {
				$('body').removeClass('sticky-header-on');
			}

		}).resize(function() {

			setTimeout(function() {
				if ( $('#wpadminbar').length && $('#wpadminbar').is(':visible') ) {
					$('.site-sticky-header').css('top', $('#wpadminbar').height());
				}
			}, 500)

		});

	}

	/* ----------------------------------------
	 Navigation
	 ---------------------------------------- */

	App.modules.navInit = function() {

		return {
			init : function () {

				this.navMain = $('.main-navigation');
				this.navPanel = $('.mad-nav-panel');
				this.wrapper = $('.wrapper-container');

				this.bindEvents();
				this.createResponsiveButtons();
				this.navProcess();

				if ( App.ISTOUCH ) {
					this.touchNavEvent();
				}
			},

			touchNavEvent: function () {
				var clicked = false;

				$('li.menu-item-has-children > a, li.cat-parent > a, li.page-item-has-children > a', this.navMain).on( App.EVENT, function (e) {
					if ( clicked != this ) {
						e.preventDefault();
						clicked = this;
					}
				});

			},

			navProcess: function () {

				var self = this;

				if ( Modernizr.es6array ) {
					new Matebook_ML_Menu(this.navPanel[0], {
						breadcrumbsCtrl : false, // show breadcrumbs
						// initialBreadcrumb : 'all', // initial breadcrumb text
						backCtrl : true, // show back button
					});
				}

				$('ul.cats-tabs-caption').on('mouseover', 'li', function() {
					$(this)
						.closest('.cats-tabs')
						.find('.cats-tab-content')
						.removeClass('active')
						.eq($(this).index())
						.addClass('active');
				});

				this.navButton.on(App.EVENT, function (e) {
					e.preventDefault();
					self.navPanel.toggleClass('menu--open');
				});

				this.navHide.on(App.EVENT, function (e) {
					e.preventDefault();
					self.navPanel.removeClass('menu--open');
				});

			},

			bindEvents: function() {
				this.navMain.on('mouseenter.smart touchstart.mobilenav', 'li[class*="menu-item-has-children"], li[class*="page_item_has_children"]', this.smartPosition);
			},

			smartPosition: function(e) {

				var $this = $(this),
					$wW = $(window).width();

				var child = $this.children('.sub-menu-wrap, ul.children, ul.sub-menu'),
					transformCoeficient = child.outerWidth() - child.outerWidth() * .85;

				if ( App.RTL ) {

					if ( child.offset().left - transformCoeficient < 0 ) child.addClass('menu-reverse');

				} else {
					var posX = child.offset().left,
						oW = child.outerWidth();

					if ( posX + oW > $wW ) {
						child.addClass('menu-reverse');
					}
				}

			},

			createResponsiveButtons : function () {

				this.navButton = $('#site-nav-button');

				this.navHide = $('<a></a>', {
					'id': 'advanced-menu-hide',
					'class': 'advanced-menu-hide',
					'href' : 'javascript:void(0)'
				}).prependTo(this.navPanel);

			},
		}.init();

	}

	$.extend({
		isjQuery: function(element, elementExists) {
			if(element === undefined || element === null) return false;

			if(elementExists === undefined) {
				return element instanceof jQuery;
			}
			else {
				return $.isjQuery(element) && element.length;
			}
		},
	});

	$.fn.extend({
		jQueryImagesLoaded : function () {
			var $imgs = this.find('img[src!=""]');

			if (!$imgs.length) {return $.Deferred().resolve().promise();}

			var dfds = [];

			$imgs.each(function(){
				var dfd = $.Deferred();
				dfds.push(dfd);
				var img = new Image();
				img.onload = function(){dfd.resolve();};
				img.onerror = function(){dfd.resolve();};
				img.src = this.src;
			});

			return $.when.apply($,dfds);
		},
		searchClick: function (option) {
			if (!this.length) return this;
			return this.each(function () {
				var $this = $(this), data = $this.data('searchClick'),
					options = typeof option == 'object' && option;
				if ( !data ) {
					$this.data('searchClick', new $.searchClick(this, options));
				}
			});
		}
	});

	$doc.ready(function() {
		App.afterDOMReady();
	});

	if ( $.fn.theiaStickySidebar ) {
		$(window).on('load resize', function() {
			if ( $(window).width() > 992 && $('.sticky-bar').length ) {
				$('.site-sidebar.sticky-bar').each(function() {
					$(this).theiaStickySidebar({
						'containerSelector': '',
						'additionalMarginTop': $('.site-header').outerHeight(true) + parseInt($('.site-main').css('padding-top'), 10),
						'additionalMarginBottom': 0,
						'updateSidebarHeight': true,
						'minWidth': 0,
						'disableOn<a href="https://www.jqueryscript.net/tags.php?/Responsive/">Responsive</a>Layouts': true,
						'sidebarBehavior': 'modern',
						'defaultPosition': 'relative',
						'namespace': 'TSS'
					});
				})
			}
		});
	}

	return App;

})(window.jQuery);
