(function( $ ) {

	// Dropdown toggle handler.
	function toggle( e ) {
		var $ct = $( e.currentTarget ).closest( '.ps-js-dropdown' ),
			$dd = $ct.find( '.ps-js-dropdown-menu' ),
			$doc = $( document ),
			guid = $ct.data( 'ps-guid' );

		// Prevent default action for link href="#".
		e.preventDefault();

		// Add guid data.
		if ( ! guid ) {
			guid = _.uniqueId( 'ps-dropdown-' );
			$ct.data( 'ps-guid', guid );
		}

		// Hide dropdown if it is currently visible.
		if ( $dd.is( ':visible' ) ) {
			e.stopPropagation();

			$doc.off( 'click.' + guid );
			$dd.hide();
			$ct.removeClass('active')
			return;
		}

		$dd.show();
		$ct.addClass('active');
		$doc.one( 'click.' + guid, function() {
			$dd.hide();
			$ct.removeClass('active')
		});
	}

	$(function() {
		$(document).off('click.ps-dropdown').on( 'click.mod-ps-dropdown', '.ps-js-dropdown-toggle', toggle );
	});

})( jQuery );


var MadStickyHeaderSection = (function($){
	'use strict';

	if(!$) return;

	var _config = {
		cssPrefix: 'mad-',
		resizeDelay: 50,
		classMap: {
			hiddenSection: 'header-section--sticky-hidden',
			active: 'header-section--sticked',
			container: 'header',
			spaceException: 'header--transparent',
			exceptionForSpaceException: 'header--breadcrumb-part'
		},
		breakpointMap: {
			xs: 0,
			sm: 576,
			md: 768,
			lg: 992,
			xl: 1200,
			xxl: 1380,
			xxxl: 1600
		},
		animationDuration: 400,
		animationEasing: 'linear'
	};

	var $body = $('body');

	function StickySection($element, config) {
		this.$element = $element;
		this.config = $.extend(true, {}, _config, (config || {}));

		this.updateDocumentState();

		Object.defineProperties(this, {
			activeClass: {
				get: function() {
					return this.config.cssPrefix + this.config.classMap.active;
				}
			},
			sticked: {
				get: function() {
					return this.$element.hasClass(this.activeClass);
				}
			},
			$hiddenSections: {
				get: function() {
					return this.$element.find('.' + this.config.cssPrefix + this.config.classMap.hiddenSection);
				}
			},
			isSuitable: {
				get: function() {
					var $w = $(window);

					return this.$element.hasClass(this.config.cssPrefix + 'header-section--sticky-xs') && $w.width() > this.config.breakpointMap.xs ||
						this.$element.hasClass(this.config.cssPrefix + 'header-section--sticky-sm') && $w.width() > this.config.breakpointMap.sm ||
						this.$element.hasClass(this.config.cssPrefix + 'header-section--sticky-md') && $w.width() > this.config.breakpointMap.md ||
						this.$element.hasClass(this.config.cssPrefix + 'header-section--sticky-lg') && $w.width() > this.config.breakpointMap.lg ||
						this.$element.hasClass(this.config.cssPrefix + 'header-section--sticky-xl') && $w.width() > this.config.breakpointMap.xl ||
						this.$element.hasClass(this.config.cssPrefix + 'header-section--sticky-xxl') && $w.width() > this.config.breakpointMap.xxl ||
						this.$element.hasClass(this.config.cssPrefix + 'header-section--sticky-xxxl') && $w.width() > this.config.breakpointMap.xxxl;
				}
			},
			$container: {
				get: function() {
					return this.$element.closest('.' + this.config.cssPrefix + this.config.classMap.container);
				}
			},
			spaceExceptionClass: {
				get: function() {
					return this.config.cssPrefix + this.config.classMap.spaceException;
				}
			},
			exceptionForSpaceExceptionClass: {
				get: function() {
					return this.config.cssPrefix + this.config.classMap.exceptionForSpaceException;
				}
			}
		});

		this._bindEvents();
	};

	StickySection.prototype.updateDocumentState = function() {
		this.topOffset = this.$element.offset().top;
		this.defaultBodyPadding = parseInt($body.css('padding-top'), 10);

		return this;
	};

	StickySection.prototype.sticky = function() {
		this.$element.addClass(this.activeClass);
		this._addSpace().hideSections();

		return this;
	};

	StickySection.prototype.unsticky = function () {
		this.$element.removeClass(this.activeClass);
		this._removeSpace().showSections();

		return this;
	};

	StickySection.prototype._addSpace = function() {
		if(!this.$container.hasClass(this.spaceExceptionClass) || this.$container.hasClass(this.exceptionForSpaceExceptionClass)) {
			$body.css('padding-top', this.defaultBodyPadding + 32 + this.$element.outerHeight()).trigger('spaceadded.milenia.stickysection');
		}

		return this;
	};

	StickySection.prototype._removeSpace = function() {
		if(!this.$container.hasClass(this.spaceExceptionClass) || this.$container.hasClass(this.exceptionForSpaceExceptionClass)) {
			$body.css('padding-top', this.defaultBodyPadding).trigger('spaceremoved.milenia.stickysection');
		}

		return this;
	};

	StickySection.prototype.hideSections = function() {
		var self = this;

		if(this.$hiddenSections.length) {
			this.$hiddenSections.stop().slideUp({
				easing: self.config.animationEasing,
				duration: self.config.animationDuration,
				step: function() {
					self._addSpace();
				},
				complete: function() {
					$(this).css('height', '');
				}
			});
		}

		return this.$hiddenSections;
	};

	StickySection.prototype.showSections = function() {
		var self = this;

		if(this.$hiddenSections.length) {
			this.$hiddenSections.stop().slideDown({
				easing: self.config.animationEasing,
				duration: self.config.animationDuration,
				complete: function() {
					$(this).css('height', '');
				}
			});
		}

		return this.$hiddenSections;
	};

	StickySection.prototype._bindEvents = function() {
		var $w = $(window),
			self = this;

		$w.on('scroll.MadStickyHeaderSection', function(event) {

			if($w.scrollTop() > self.topOffset && !self.sticked && self.isSuitable) {
				self.sticky();
			}
			else if($w.scrollTop() <= self.topOffset && self.sticked && self.isSuitable) {
				self.unsticky();
			}
		})
			.on('resize.MadStickyHeaderSection', function(event) {
				if(self.resizeTimeOutId) clearTimeout(self.resizeTimeOutId);

				self.resizeTimeOutId = setTimeout(function() {
					self.unsticky().updateDocumentState();
					if($w.scrollTop() > self.topOffset && !self.sticked && self.isSuitable) self.sticky();

					if(!self.isSuitable) self.showSections();

				}, self.config.resizeDelay);
			})
			.trigger('scroll.MadStickyHeaderSection');
	};

	return StickySection;

})(window.jQuery);

jQuery.easing.jswing=jQuery.easing.swing;
jQuery.extend(jQuery.easing,{def:"easeOutQuad",swing:function(e,a,c,b,d){return jQuery.easing[jQuery.easing.def](e,a,c,b,d)},easeInQuad:function(e,a,c,b,d){return b*(a/=d)*a+c},easeOutQuad:function(e,a,c,b,d){return-b*(a/=d)*(a-2)+c},easeInOutQuad:function(e,a,c,b,d){return 1>(a/=d/2)?b/2*a*a+c:-b/2*(--a*(a-2)-1)+c},easeInCubic:function(e,a,c,b,d){return b*(a/=d)*a*a+c},easeOutCubic:function(e,a,c,b,d){return b*((a=a/d-1)*a*a+1)+c},easeInOutCubic:function(e,a,c,b,d){return 1>(a/=d/2)?b/2*a*a*a+c:
	b/2*((a-=2)*a*a+2)+c},easeInQuart:function(e,a,c,b,d){return b*(a/=d)*a*a*a+c},easeOutQuart:function(e,a,c,b,d){return-b*((a=a/d-1)*a*a*a-1)+c},easeInOutQuart:function(e,a,c,b,d){return 1>(a/=d/2)?b/2*a*a*a*a+c:-b/2*((a-=2)*a*a*a-2)+c},easeInQuint:function(e,a,c,b,d){return b*(a/=d)*a*a*a*a+c},easeOutQuint:function(e,a,c,b,d){return b*((a=a/d-1)*a*a*a*a+1)+c},easeInOutQuint:function(e,a,c,b,d){return 1>(a/=d/2)?b/2*a*a*a*a*a+c:b/2*((a-=2)*a*a*a*a+2)+c},easeInSine:function(e,a,c,b,d){return-b*Math.cos(a/
		d*(Math.PI/2))+b+c},easeOutSine:function(e,a,c,b,d){return b*Math.sin(a/d*(Math.PI/2))+c},easeInOutSine:function(e,a,c,b,d){return-b/2*(Math.cos(Math.PI*a/d)-1)+c},easeInExpo:function(e,a,c,b,d){return 0==a?c:b*Math.pow(2,10*(a/d-1))+c},easeOutExpo:function(e,a,c,b,d){return a==d?c+b:b*(-Math.pow(2,-10*a/d)+1)+c},easeInOutExpo:function(e,a,c,b,d){return 0==a?c:a==d?c+b:1>(a/=d/2)?b/2*Math.pow(2,10*(a-1))+c:b/2*(-Math.pow(2,-10*--a)+2)+c},easeInCirc:function(e,a,c,b,d){return-b*(Math.sqrt(1-(a/=d)*
		a)-1)+c},easeOutCirc:function(e,a,c,b,d){return b*Math.sqrt(1-(a=a/d-1)*a)+c},easeInOutCirc:function(e,a,c,b,d){return 1>(a/=d/2)?-b/2*(Math.sqrt(1-a*a)-1)+c:b/2*(Math.sqrt(1-(a-=2)*a)+1)+c},easeInElastic:function(e,a,c,b,d){e=0;var f=b;if(0==a)return c;if(1==(a/=d))return c+b;e||(e=.3*d);f<Math.abs(b)?(f=b,b=e/4):b=e/(2*Math.PI)*Math.asin(b/f);return-(f*Math.pow(2,10*--a)*Math.sin(2*(a*d-b)*Math.PI/e))+c},easeOutElastic:function(e,a,c,b,d){var f=0,g=b;if(0==a)return c;if(1==(a/=d))return c+b;f||
(f=.3*d);g<Math.abs(b)?(g=b,e=f/4):e=f/(2*Math.PI)*Math.asin(b/g);return g*Math.pow(2,-10*a)*Math.sin(2*(a*d-e)*Math.PI/f)+b+c},easeInOutElastic:function(e,a,c,b,d){var f=0,g=b;if(0==a)return c;if(2==(a/=d/2))return c+b;f||(f=.3*d*1.5);g<Math.abs(b)?(g=b,e=f/4):e=f/(2*Math.PI)*Math.asin(b/g);return 1>a?-.5*g*Math.pow(2,10*--a)*Math.sin(2*(a*d-e)*Math.PI/f)+c:g*Math.pow(2,-10*--a)*Math.sin(2*(a*d-e)*Math.PI/f)*.5+b+c},easeInBack:function(e,a,c,b,d,f){void 0==f&&(f=1.70158);return b*(a/=d)*a*((f+1)*
	a-f)+c},easeOutBack:function(e,a,c,b,d,f){void 0==f&&(f=1.70158);return b*((a=a/d-1)*a*((f+1)*a+f)+1)+c},easeInOutBack:function(e,a,c,b,d,f){void 0==f&&(f=1.70158);return 1>(a/=d/2)?b/2*a*a*(((f*=1.525)+1)*a-f)+c:b/2*((a-=2)*a*(((f*=1.525)+1)*a+f)+2)+c},easeInBounce:function(e,a,c,b,d){return b-jQuery.easing.easeOutBounce(e,d-a,0,b,d)+c},easeOutBounce:function(e,a,c,b,d){return(a/=d)<1/2.75?7.5625*b*a*a+c:a<2/2.75?b*(7.5625*(a-=1.5/2.75)*a+.75)+c:a<2.5/2.75?b*(7.5625*(a-=2.25/2.75)*a+.9375)+c:b*(7.5625*
	(a-=2.625/2.75)*a+.984375)+c},easeInOutBounce:function(e,a,c,b,d){return a<d/2?.5*jQuery.easing.easeInBounce(e,2*a,0,b,d)+c:.5*jQuery.easing.easeOutBounce(e,2*a-d,0,b,d)+.5*b+c}});
;(function($){
	'use strict';

	/**
	 * Mad_Custom_Selects
	 *
	 * @constructor
	 * @object options
	 **/
	function MadCustomSelects(options) {
		this.collection = $();

		this.config = {
			target: '.mad-custom-select',
			cssPrefix: 'mad-'
		};

		options = options || {};
		$.extend(this.config, options);

		this.collection = this.collection.add($(this.config.target));

		if(this.collection.length) this.build().bindEvents();
	}


	/**
	 * Creates necessary select elements and adds them to container element
	 **/
	MadCustomSelects.prototype.build = function(){

		var self = this;

		this.collection.each(function(index, element){
			var $element = $(element),
				$select = $element.children('select'),
				$selectedOption,
				$optionsList,
				$options,
				selectedFlag = false;

			if(!$select.length) return;

			$select.hide();

			$options = $select.find('option');

			$selectedOption = $('<div></div>', {
				'class': self.config.cssPrefix + 'selected-option',
				text: $select.data('default-text')
			});

			$optionsList = $('<ul></ul>', {
				'class': self.config.cssPrefix + 'options-list'
			});

			for(var i = 0, l = $options.length; i < l; i++){
				var option = $options.eq(i);

				var li = $('<li></li>', {
					'text': option.text(),
					'data-value': option.val()
				});

				if(option.attr('selected')){
					li.addClass(self.config.cssPrefix + 'active');
					$selectedOption.text(option.text());
					selectedFlag = true;
				}

				$optionsList.append(li);

			}

			if(!$select.data('default-text') && !selectedFlag){

				$selectedOption.text($options.eq(0).text());
				$optionsList.children('li').eq(0).addClass(self.config.cssPrefix + 'active');

			}

			$element.append($selectedOption);
			$element.append($optionsList);
		});

		return this;

	};

	/**
	 * Returns custom select to the default state.
	 **/
	MadCustomSelects.prototype.toDefaultState = function(e){

		e.preventDefault();
		e.stopPropagation();

		var $this = $(this),
			self = e.data.self,
			$element = $this.closest(self.config.target);

		if($element.length && !$element.hasClass(self.config.cssPrefix + 'opened')){
			$element.removeClass(self.config.cssPrefix + 'over');
		}

	};

	/**
	 * Binds events to select elements
	 **/
	MadCustomSelects.prototype.bindEvents = function(){

		var self = this;

		$('body').on('click.MadCustomSelects', this.config.target + ' .' + this.config.cssPrefix + 'selected-option', function(e) {
			var $element = $(this).closest(self.config.target);

			if($element.length) {
				$element.addClass(self.config.cssPrefix + 'over');
				$element.toggleClass(self.config.cssPrefix + 'opened');
			}

			e.stopPropagation();
		})
			.on('focus.MadCustomSelects', this.config.target + ' select', function(e) {
				var $element = $(this).closest(self.config.target);

				$element.addClass(self.config.cssPrefix + 'opened');
				e.preventDefault();
			})
			.on('click.MadCustomSelects', this.config.target + ' .' + this.config.cssPrefix + 'options-list li', function(e) {

				var $this = $(this),
					value = $this.data('value'),
					$element = $this.closest(self.config.target),
					$select = $element.find('select'),
					$selectedOption = $element.find('.' + self.config.cssPrefix + 'selected-option'),
					$options = $select.find('option'),
					$currentOption;

				$this.addClass(self.config.cssPrefix + 'active').siblings().removeClass(self.config.cssPrefix + 'active');

				$selectedOption.text($this.text());

				if($options.length) {
					$currentOption = $options.filter('[value="'+value+'"]');
					$options.not($currentOption).removeAttr('selected');
					if($currentOption.length) {
						$currentOption.attr('selected', 'true');
					}
				}

				$select.val(value);
				$select.trigger('change');
				$element.removeClass(self.config.cssPrefix + 'opened');

				e.stopPropagation();
			})
			.on('webkitTransitionEnd otransitionend oTransitionEnd msTransitionEnd transitionend', this.config.target + ' .' + this.config.cssPrefix + 'options-list', {self: this},  this.toDefaultState);


		$(document).on('click.selectFocusOut', function(e){
			e.stopPropagation();
			if( !$(e.target).closest('.' + self.config.cssPrefix + 'custom-select').length ) {
				$('.' + self.config.cssPrefix +  'custom-select').removeClass(self.config.cssPrefix + 'opened');
			}
		});

	};

	$.extend({
		MadCustomSelects: function(options) {
			return new MadCustomSelects(options);
		}
	});

})(jQuery);


/*!
 * Theia Sticky Sidebar v1.7.0
 * https://github.com/WeCodePixels/theia-sticky-sidebar
 *
 * Glues your website's sidebars, making them permanently visible while scrolling.
 *
 * Copyright 2013-2016 WeCodePixels and other contributors
 * Released under the MIT license
 */

(function ($) {
	$.fn.theiaStickySidebar = function (options) {
		var defaults = {
			'containerSelector': '',
			'additionalMarginTop': 0,
			'additionalMarginBottom': 0,
			'updateSidebarHeight': true,
			'minWidth': 0,
			'disableOnResponsiveLayouts': true,
			'sidebarBehavior': 'modern',
			'defaultPosition': 'relative',
			'namespace': 'TSS'
		};
		options = $.extend(defaults, options);

		// Validate options
		options.additionalMarginTop = parseInt(options.additionalMarginTop) || 0;
		options.additionalMarginBottom = parseInt(options.additionalMarginBottom) || 0;

		tryInitOrHookIntoEvents(options, this);

		// Try doing init, otherwise hook into window.resize and document.scroll and try again then.
		function tryInitOrHookIntoEvents(options, $that) {
			var success = tryInit(options, $that);

			if (!success) {
				console.log('TSS: Body width smaller than options.minWidth. Init is delayed.');

				$(document).on('scroll.' + options.namespace, function (options, $that) {
					return function (evt) {
						var success = tryInit(options, $that);

						if (success) {
							$(this).unbind(evt);
						}
					};
				}(options, $that));
				$(window).on('resize.' + options.namespace, function (options, $that) {
					return function (evt) {
						var success = tryInit(options, $that);

						if (success) {
							$(this).unbind(evt);
						}
					};
				}(options, $that))
			}
		}

		// Try doing init if proper conditions are met.
		function tryInit(options, $that) {
			if (options.initialized === true) {
				return true;
			}

			if ($('body').width() < options.minWidth) {
				return false;
			}

			init(options, $that);

			return true;
		}

		// Init the sticky sidebar(s).
		function init(options, $that) {
			options.initialized = true;

			// Add CSS
			var existingStylesheet = $('#theia-sticky-sidebar-stylesheet-' + options.namespace);
			if (existingStylesheet.length === 0) {
				$('head').append($('<style id="theia-sticky-sidebar-stylesheet-' + options.namespace + '">.theiaStickySidebar:after {content: ""; display: table; clear: both;}</style>'));
			}

			$that.each(function () {
				var o = {};

				o.sidebar = $(this);

				// Save options
				o.options = options || {};

				// Get container
				o.container = $(o.options.containerSelector);
				if (o.container.length == 0) {
					o.container = o.sidebar.parent();
				}

				// Create sticky sidebar
				o.sidebar.parents().css('-webkit-transform', 'none'); // Fix for WebKit bug - https://code.google.com/p/chromium/issues/detail?id=20574
				o.sidebar.css({
					'position': o.options.defaultPosition,
					'overflow': 'visible',
					// The "box-sizing" must be set to "content-box" because we set a fixed height to this element when the sticky sidebar has a fixed position.
					'-webkit-box-sizing': 'border-box',
					'-moz-box-sizing': 'border-box',
					'box-sizing': 'border-box'
				});

				// Get the sticky sidebar element. If none has been found, then create one.
				o.stickySidebar = o.sidebar.find('.theiaStickySidebar');
				if (o.stickySidebar.length == 0) {
					// Remove <script> tags, otherwise they will be run again when added to the stickySidebar.
					var javaScriptMIMETypes = /(?:text|application)\/(?:x-)?(?:javascript|ecmascript)/i;
					o.sidebar.find('script').filter(function (index, script) {
						return script.type.length === 0 || script.type.match(javaScriptMIMETypes);
					}).remove();

					o.stickySidebar = $('<div>').addClass('theiaStickySidebar').append(o.sidebar.children());
					o.sidebar.append(o.stickySidebar);
				}

				// Get existing top and bottom margins and paddings
				o.marginBottom = parseInt(o.sidebar.css('margin-bottom'));
				o.paddingTop = parseInt(o.sidebar.css('padding-top'));
				o.paddingBottom = parseInt(o.sidebar.css('padding-bottom'));

				// Add a temporary padding rule to check for collapsable margins.
				var collapsedTopHeight = o.stickySidebar.offset().top;
				var collapsedBottomHeight = o.stickySidebar.outerHeight();
				o.stickySidebar.css('padding-top', 1);
				o.stickySidebar.css('padding-bottom', 1);
				collapsedTopHeight -= o.stickySidebar.offset().top;
				collapsedBottomHeight = o.stickySidebar.outerHeight() - collapsedBottomHeight - collapsedTopHeight;
				if (collapsedTopHeight == 0) {
					o.stickySidebar.css('padding-top', 0);
					o.stickySidebarPaddingTop = 0;
				}
				else {
					o.stickySidebarPaddingTop = 1;
				}

				if (collapsedBottomHeight == 0) {
					o.stickySidebar.css('padding-bottom', 0);
					o.stickySidebarPaddingBottom = 0;
				}
				else {
					o.stickySidebarPaddingBottom = 1;
				}

				// We use this to know whether the user is scrolling up or down.
				o.previousScrollTop = null;

				// Scroll top (value) when the sidebar has fixed position.
				o.fixedScrollTop = 0;

				// Set sidebar to default values.
				resetSidebar();

				o.onScroll = function (o) {
					// Stop if the sidebar isn't visible.
					if (!o.stickySidebar.is(":visible")) {
						return;
					}

					// Stop if the window is too small.
					if ($('body').width() < o.options.minWidth) {
						resetSidebar();
						return;
					}

					// Stop if the sidebar width is larger than the container width (e.g. the theme is responsive and the sidebar is now below the content)
					if (o.options.disableOnResponsiveLayouts) {
						var sidebarWidth = o.sidebar.outerWidth(o.sidebar.css('float') == 'none');

						if (sidebarWidth + 50 > o.container.width()) {
							resetSidebar();
							return;
						}
					}

					var scrollTop = $(document).scrollTop();
					var position = 'static';

					// If the user has scrolled down enough for the sidebar to be clipped at the top, then we can consider changing its position.
					if (scrollTop >= o.sidebar.offset().top + (o.paddingTop - o.options.additionalMarginTop)) {
						// The top and bottom offsets, used in various calculations.
						var offsetTop = o.paddingTop + options.additionalMarginTop;
						var offsetBottom = o.paddingBottom + o.marginBottom + options.additionalMarginBottom;

						// All top and bottom positions are relative to the window, not to the parent elemnts.
						var containerTop = o.sidebar.offset().top;
						var containerBottom = o.sidebar.offset().top + getClearedHeight(o.container);

						// The top and bottom offsets relative to the window screen top (zero) and bottom (window height).
						var windowOffsetTop = 0 + options.additionalMarginTop;
						var windowOffsetBottom;

						var sidebarSmallerThanWindow = (o.stickySidebar.outerHeight() + offsetTop + offsetBottom) < $(window).height();
						if (sidebarSmallerThanWindow) {
							windowOffsetBottom = windowOffsetTop + o.stickySidebar.outerHeight();
						}
						else {
							windowOffsetBottom = $(window).height() - o.marginBottom - o.paddingBottom - options.additionalMarginBottom;
						}

						var staticLimitTop = containerTop - scrollTop + o.paddingTop;
						var staticLimitBottom = containerBottom - scrollTop - o.paddingBottom - o.marginBottom;

						var top = o.stickySidebar.offset().top - scrollTop;
						var scrollTopDiff = o.previousScrollTop - scrollTop;

						// If the sidebar position is fixed, then it won't move up or down by itself. So, we manually adjust the top coordinate.
						if (o.stickySidebar.css('position') == 'fixed') {
							if (o.options.sidebarBehavior == 'modern') {
								top += scrollTopDiff;
							}
						}

						if (o.options.sidebarBehavior == 'stick-to-top') {
							top = options.additionalMarginTop;
						}

						if (o.options.sidebarBehavior == 'stick-to-bottom') {
							top = windowOffsetBottom - o.stickySidebar.outerHeight();
						}

						if (scrollTopDiff > 0) { // If the user is scrolling up.
							top = Math.min(top, windowOffsetTop);
						}
						else { // If the user is scrolling down.
							top = Math.max(top, windowOffsetBottom - o.stickySidebar.outerHeight());
						}

						top = Math.max(top, staticLimitTop);

						top = Math.min(top, staticLimitBottom - o.stickySidebar.outerHeight());

						// If the sidebar is the same height as the container, we won't use fixed positioning.
						var sidebarSameHeightAsContainer = o.container.height() == o.stickySidebar.outerHeight();

						if (!sidebarSameHeightAsContainer && top == windowOffsetTop) {
							position = 'fixed';
						}
						else if (!sidebarSameHeightAsContainer && top == windowOffsetBottom - o.stickySidebar.outerHeight()) {
							position = 'fixed';
						}
						else if (scrollTop + top - o.sidebar.offset().top - o.paddingTop <= options.additionalMarginTop) {
							// Stuck to the top of the page. No special behavior.
							position = 'static';
						}
						else {
							// Stuck to the bottom of the page.
							position = 'absolute';
						}
					}

					/*
					 * Performance notice: It's OK to set these CSS values at each resize/scroll, even if they don't change.
					 * It's way slower to first check if the values have changed.
					 */
					if (position == 'fixed') {
						var scrollLeft = $(document).scrollLeft();

						o.stickySidebar.css({
							'position': 'fixed',
							'width': getWidthForObject(o.stickySidebar) + 'px',
							'transform': 'translateY(' + top + 'px)',
							'left': (o.sidebar.offset().left + parseInt(o.sidebar.css('padding-left')) - scrollLeft) + 'px',
							'top': '0px'
						});
					}
					else if (position == 'absolute') {
						var css = {};

						if (o.stickySidebar.css('position') != 'absolute') {
							css.position = 'absolute';
							css.transform = 'translateY(' + (scrollTop + top - o.sidebar.offset().top - o.stickySidebarPaddingTop - o.stickySidebarPaddingBottom) + 'px)';
							css.top = '0px';
						}

						css.width = getWidthForObject(o.stickySidebar) + 'px';
						css.left = '';

						o.stickySidebar.css(css);
					}
					else if (position == 'static') {
						resetSidebar();
					}

					if (position != 'static') {
						if (o.options.updateSidebarHeight == true) {
							o.sidebar.css({
								'min-height': o.stickySidebar.outerHeight() + o.stickySidebar.offset().top - o.sidebar.offset().top + o.paddingBottom
							});
						}
					}

					o.previousScrollTop = scrollTop;
				};

				// Initialize the sidebar's position.
				o.onScroll(o);

				// Recalculate the sidebar's position on every scroll and resize.
				$(document).on('scroll.' + o.options.namespace, function (o) {
					return function () {
						o.onScroll(o);
					};
				}(o));
				$(window).on('resize.' + o.options.namespace, function (o) {
					return function () {
						o.stickySidebar.css({'position': 'static'});
						o.onScroll(o);
					};
				}(o));

				// Recalculate the sidebar's position every time the sidebar changes its size.
				if (typeof ResizeSensor !== 'undefined') {
					new ResizeSensor(o.stickySidebar[0], function (o) {
						return function () {
							o.onScroll(o);
						};
					}(o));
				}

				// Reset the sidebar to its default state
				function resetSidebar() {
					o.fixedScrollTop = 0;
					o.sidebar.css({
						'min-height': '1px'
					});
					o.stickySidebar.css({
						'position': 'static',
						'width': '',
						'transform': 'none'
					});
				}

				// Get the height of a div as if its floated children were cleared. Note that this function fails if the floats are more than one level deep.
				function getClearedHeight(e) {
					var height = e.height();

					e.children().each(function () {
						height = Math.max(height, $(this).height());
					});

					return height;
				}
			});
		}

		function getWidthForObject(object) {
			var width;

			try {
				width = object[0].getBoundingClientRect().width;
			}
			catch (err) {
			}

			if (typeof width === "undefined") {
				width = object.width();
			}

			return width;
		}

		return this;
	}
})(jQuery);